@@ -18,7 +18,7 @@ use Path::Tiny;
 use IO::Handle;
 use POSIX qw/:errno_h/;
 
-our $VERSION     = '0.18';
+our $VERSION     = '0.19';
 our @EXPORT_OK   = qw/hosts_from_map is_host multi_run shell_quote tmux/;
 our %EXPORT_TAGS = ();
 
@@ -94,7 +94,8 @@ sub multi_run {
     # loop over each host and run the remote command
     for my $host (@$hosts) {
         my $cmd = "ssh $host " . shell_quote($remote_cmd);
-        print "$cmd\n" if $option->{verbose} || $option->{test};
+        print "$host -\n" if $option->{verbose};
+        print "$cmd\n" if $option->{verbose} > 1 || $option->{test};
         next if $option->{test};
 
         if ( $option->{parallel} ) {
@@ -267,7 +268,7 @@ App::MultiSsh - Multi host ssh executer
 
 =head1 VERSION
 
-This documentation refers to App::MultiSsh version 0.18
+This documentation refers to App::MultiSsh version 0.19
 
 =head1 SYNOPSIS
 
@@ -288,7 +289,7 @@ This documentation refers to App::MultiSsh version 0.18
 
 Splits C<$host> into all hosts that it represents.
 
-eg
+e.g.
 
   host0[012] -> host00, host01, host02
   host0[0-2] -> host00, host01, host02
